==> fms-1.93.0-sources.jar: software/amazon/awscdk/services/fms/CfnNotificationChannelProps.java <==
package software.amazon.awscdk.services.fms;

/**
 * Properties for defining a `AWS::FMS::NotificationChannel`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:21.592Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.fms.$Module.class, fqn = "@aws-cdk/aws-fms.CfnNotificationChannelProps")
@software.amazon.jsii.Jsii.Proxy(CfnNotificationChannelProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnNotificationChannelProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::FMS::NotificationChannel.SnsRoleName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getSnsRoleName();

    /**
     * `AWS::FMS::NotificationChannel.SnsTopicArn`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getSnsTopicArn();

    /**
     * @return a {@link Builder} of {@link CfnNotificationChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnNotificationChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnNotificationChannelProps> {
        private java.lang.String snsRoleName;
        private java.lang.String snsTopicArn;

        /**
         * Sets the value of {@link CfnNotificationChannelProps#getSnsRoleName}
         * @param snsRoleName `AWS::FMS::NotificationChannel.SnsRoleName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder snsRoleName(java.lang.String snsRoleName) {
            this.snsRoleName = snsRoleName;
            return this;
        }

        /**
         * Sets the value of {@link CfnNotificationChannelProps#getSnsTopicArn}
         * @param snsTopicArn `AWS::FMS::NotificationChannel.SnsTopicArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder snsTopicArn(java.lang.String snsTopicArn) {
            this.snsTopicArn = snsTopicArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnNotificationChannelProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnNotificationChannelProps build() {
            return new Jsii$Proxy(snsRoleName, snsTopicArn);
        }
    }

    /**
     * An implementation for {@link CfnNotificationChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnNotificationChannelProps {
        private final java.lang.String snsRoleName;
        private final java.lang.String snsTopicArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.snsRoleName = software.amazon.jsii.Kernel.get(this, "snsRoleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.snsTopicArn = software.amazon.jsii.Kernel.get(this, "snsTopicArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String snsRoleName, final java.lang.String snsTopicArn) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.snsRoleName = java.util.Objects.requireNonNull(snsRoleName, "snsRoleName is required");
            this.snsTopicArn = java.util.Objects.requireNonNull(snsTopicArn, "snsTopicArn is required");
        }

        @Override
        public final java.lang.String getSnsRoleName() {
            return this.snsRoleName;
        }

        @Override
        public final java.lang.String getSnsTopicArn() {
            return this.snsTopicArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("snsRoleName", om.valueToTree(this.getSnsRoleName()));
            data.set("snsTopicArn", om.valueToTree(this.getSnsTopicArn()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-fms.CfnNotificationChannelProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnNotificationChannelProps.Jsii$Proxy that = (CfnNotificationChannelProps.Jsii$Proxy) o;

            if (!snsRoleName.equals(that.snsRoleName)) return false;
            return this.snsTopicArn.equals(that.snsTopicArn);
        }

        @Override
        public final int hashCode() {
            int result = this.snsRoleName.hashCode();
            result = 31 * result + (this.snsTopicArn.hashCode());
            return result;
        }
    }
}

==> fms-1.182.0-sources.jar: software/amazon/awscdk/services/fms/CfnNotificationChannelProps.java <==
package software.amazon.awscdk.services.fms;

/**
 * Properties for defining a `CfnNotificationChannel`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.fms.*;
 * CfnNotificationChannelProps cfnNotificationChannelProps = CfnNotificationChannelProps.builder()
 *         .snsRoleName("snsRoleName")
 *         .snsTopicArn("snsTopicArn")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:34.954Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.fms.$Module.class, fqn = "@aws-cdk/aws-fms.CfnNotificationChannelProps")
@software.amazon.jsii.Jsii.Proxy(CfnNotificationChannelProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnNotificationChannelProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Amazon Resource Name (ARN) of the IAM role that allows Amazon SNS to record AWS Firewall Manager activity.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getSnsRoleName();

    /**
     * The Amazon Resource Name (ARN) of the SNS topic that collects notifications from AWS Firewall Manager .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getSnsTopicArn();

    /**
     * @return a {@link Builder} of {@link CfnNotificationChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnNotificationChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnNotificationChannelProps> {
        java.lang.String snsRoleName;
        java.lang.String snsTopicArn;

        /**
         * Sets the value of {@link CfnNotificationChannelProps#getSnsRoleName}
         * @param snsRoleName The Amazon Resource Name (ARN) of the IAM role that allows Amazon SNS to record AWS Firewall Manager activity. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder snsRoleName(java.lang.String snsRoleName) {
            this.snsRoleName = snsRoleName;
            return this;
        }

        /**
         * Sets the value of {@link CfnNotificationChannelProps#getSnsTopicArn}
         * @param snsTopicArn The Amazon Resource Name (ARN) of the SNS topic that collects notifications from AWS Firewall Manager . This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder snsTopicArn(java.lang.String snsTopicArn) {
            this.snsTopicArn = snsTopicArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnNotificationChannelProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnNotificationChannelProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnNotificationChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnNotificationChannelProps {
        private final java.lang.String snsRoleName;
        private final java.lang.String snsTopicArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.snsRoleName = software.amazon.jsii.Kernel.get(this, "snsRoleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.snsTopicArn = software.amazon.jsii.Kernel.get(this, "snsTopicArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.snsRoleName = java.util.Objects.requireNonNull(builder.snsRoleName, "snsRoleName is required");
            this.snsTopicArn = java.util.Objects.requireNonNull(builder.snsTopicArn, "snsTopicArn is required");
        }

        @Override
        public final java.lang.String getSnsRoleName() {
            return this.snsRoleName;
        }

        @Override
        public final java.lang.String getSnsTopicArn() {
            return this.snsTopicArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("snsRoleName", om.valueToTree(this.getSnsRoleName()));
            data.set("snsTopicArn", om.valueToTree(this.getSnsTopicArn()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-fms.CfnNotificationChannelProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnNotificationChannelProps.Jsii$Proxy that = (CfnNotificationChannelProps.Jsii$Proxy) o;

            if (!snsRoleName.equals(that.snsRoleName)) return false;
            return this.snsTopicArn.equals(that.snsTopicArn);
        }

        @Override
        public final int hashCode() {
            int result = this.snsRoleName.hashCode();
            result = 31 * result + (this.snsTopicArn.hashCode());
            return result;
        }
    }
}
